# Pydantic ODM
###### Small async ODM for MongoDB based on Motor and Pydantic

[![PyPI version](https://badge.fury.io/py/pydantic-odm.svg)](https://pypi.org/project/pydantic-odm/)
[![PyPI downloads](https://img.shields.io/pypi/dm/pydantic-odm.svg)](https://pypi.org/project/pydantic-odm/)
[![Travis CI](https://api.travis-ci.com/i8enn/pydantic-odm.svg?branch=master)](http://travis-ci.com/i8enn/pydantic-odm)
[![codecov](https://codecov.io/gh/i8enn/pydantic-odm/branch/master/graph/badge.svg?token=DlszLTAxm0)](https://codecov.io/gh/i8enn/pydantic-odm)
